summaryrefslogtreecommitdiff
path: root/platform/android/config.cmake
diff options
context:
space:
mode:
authorKonstantin Käfer <mail@kkaefer.com>2018-12-17 15:24:11 +0100
committerKonstantin Käfer <mail@kkaefer.com>2019-01-09 10:26:53 +0100
commit6f60ccf08e4878d0688ddaefd906290a2998a148 (patch)
tree6e268040cfc1ea72fa577441398ecd790553df24 /platform/android/config.cmake
parent9acdd75d04f335313a6c491599b5c7559d6458c7 (diff)
downloadqtlocation-mapboxgl-6f60ccf08e4878d0688ddaefd906290a2998a148.tar.gz
[build] generate header maps instead of -files.txt
Diffstat (limited to 'platform/android/config.cmake')
-rw-r--r--platform/android/config.cmake12
1 files changed, 6 insertions, 6 deletions
diff --git a/platform/android/config.cmake b/platform/android/config.cmake
index b553b5b8ab..4a2361a7db 100644
--- a/platform/android/config.cmake
+++ b/platform/android/config.cmake
@@ -34,12 +34,12 @@ set(CMAKE_SHARED_LINKER_FLAGS_RELWITHDEBINFO "${CMAKE_SHARED_LINKER_FLAGS_RELWIT
## mbgl core ##
macro(mbgl_platform_core)
- # Modify platform/android/core-files.txt to change the source files for this target.
- target_sources_from_file(mbgl-core PRIVATE platform/android/core-files.txt)
+ # Modify platform/android/core-files.json to change the source files for this target.
+ target_sources_from_file(mbgl-core PRIVATE platform/android/core-files.json)
target_include_directories(mbgl-core
PUBLIC platform/default/include
- PRIVATE platform/android
+ PRIVATE platform/android/include
)
target_link_libraries(mbgl-core
@@ -57,8 +57,8 @@ endmacro()
macro(mbgl_filesource)
- # Modify platform/android/filesource-files.txt to change the source files for this target.
- target_sources_from_file(mbgl-filesource PRIVATE platform/android/filesource-files.txt)
+ # Modify platform/android/filesource-files.json to change the source files for this target.
+ target_sources_from_file(mbgl-filesource PRIVATE platform/android/filesource-files.json)
target_link_libraries(mbgl-filesource
PUBLIC sqlite
@@ -97,7 +97,7 @@ macro(mbgl_platform_test)
)
target_include_directories(mbgl-test
- PRIVATE platform/android
+ PRIVATE platform/android/include
)
target_link_libraries(mbgl-test